# TODO

## Skeleton

- [ ] Make one branch for Tkinter projects, one branch for PyGTK projects, one branch for PyQT projects, ...
- [ ] Add docs/
- [ ] Add tests/
- [ ] Add common tools: travis, ...

## Version 0.1

- [ ] TODO

